@@ -70,16 +70,19 @@ class TestUndercloudInstall(TestPluginV1):
         self.cmd.take_action(parsed_args)
 
         mock_subprocess.assert_called_with(
-            ['sudo', 'openstack', 'tripleo', 'deploy', '--standalone',
-             '--standalone-role', 'Undercloud', '--stack', 'undercloud',
-             '--local-domain=localdomain',
+            ['sudo', '--preserve-env', 'openstack', 'tripleo', 'deploy',
+             '--standalone', '--standalone-role', 'Undercloud', '--stack',
+             'undercloud', '--local-domain=localdomain',
              '--local-ip=192.168.24.1/24',
              '--templates=/usr/share/openstack-tripleo-heat-templates/',
+             '--networks-file=network_data_undercloud.yaml',
              '--heat-native', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'undercloud.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'use-dns-for-vips.yaml', '-e', '/home/stack/foo.yaml', '-e',
+             'use-dns-for-vips.yaml', '-e',
+             '/usr/share/openstack-tripleo-heat-templates/environments/'
+             'podman.yaml', '-e', '/home/stack/foo.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic.yaml',
              '-e',
@@ -138,15 +141,17 @@ class TestUndercloudInstall(TestPluginV1):
                 mock.call('/foo')
             ])
         mock_subprocess.assert_called_with(
-            ['sudo', 'openstack', 'tripleo', 'deploy', '--standalone',
-             '--standalone-role', 'Undercloud', '--stack', 'undercloud',
-             '--local-domain=localdomain',
+            ['sudo', '--preserve-env', 'openstack', 'tripleo', 'deploy',
+             '--standalone', '--standalone-role', 'Undercloud', '--stack',
+             'undercloud', '--local-domain=localdomain',
              '--local-ip=192.168.24.1/24',
              '--templates=/usertht',
              '--roles-file=foo/roles.yaml',
+             '--networks-file=network_data_undercloud.yaml',
              '--heat-native=False', '-e',
              '/usertht/environments/undercloud.yaml', '-e',
              '/usertht/environments/use-dns-for-vips.yaml', '-e',
+             '/usertht/environments/podman.yaml', '-e',
              '/home/stack/foo.yaml', '-e',
              '/usertht/environments/services/ironic.yaml', '-e',
              '/usertht/environments/services/ironic-inspector.yaml', '-e',
@@ -290,16 +295,19 @@ class TestUndercloudInstall(TestPluginV1):
         self.assertTrue(found_net_conf_override)
 
         mock_subprocess.assert_called_with(
-            ['sudo', 'openstack', 'tripleo', 'deploy', '--standalone',
-             '--standalone-role', 'Undercloud', '--stack', 'undercloud',
-             '--local-domain=localdomain',
+            ['sudo', '--preserve-env', 'openstack', 'tripleo', 'deploy',
+             '--standalone', '--standalone-role', 'Undercloud', '--stack',
+             'undercloud', '--local-domain=localdomain',
              '--local-ip=192.168.24.1/24',
              '--templates=/usr/share/openstack-tripleo-heat-templates/',
+             '--networks-file=network_data_undercloud.yaml',
              '--heat-native', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'undercloud.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'use-dns-for-vips.yaml', '-e', '/home/stack/foo.yaml', '-e',
+             'use-dns-for-vips.yaml', '-e',
+             '/usr/share/openstack-tripleo-heat-templates/environments/'
+             'podman.yaml', '-e', '/home/stack/foo.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/'
              'environments/services/masquerade-networks.yaml',
              '-e',
@@ -359,16 +367,19 @@ class TestUndercloudInstall(TestPluginV1):
         self.cmd.app_args.verbose_level = old_verbose
 
         mock_subprocess.assert_called_with(
-            ['sudo', 'openstack', 'tripleo', 'deploy', '--standalone',
-             '--standalone-role', 'Undercloud', '--stack', 'undercloud',
-             '--local-domain=localdomain',
+            ['sudo', '--preserve-env', 'openstack', 'tripleo', 'deploy',
+             '--standalone', '--standalone-role', 'Undercloud', '--stack',
+             'undercloud', '--local-domain=localdomain',
              '--local-ip=192.168.24.1/24',
              '--templates=/usr/share/openstack-tripleo-heat-templates/',
+             '--networks-file=network_data_undercloud.yaml',
              '--heat-native', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'undercloud.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'use-dns-for-vips.yaml', '-e', '/home/stack/foo.yaml', '-e',
+             'use-dns-for-vips.yaml', '-e',
+             '/usr/share/openstack-tripleo-heat-templates/environments/'
+             'podman.yaml', '-e', '/home/stack/foo.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic.yaml',
              '-e',
@@ -421,16 +432,19 @@ class TestUndercloudInstall(TestPluginV1):
         self.cmd.take_action(parsed_args)
 
         mock_subprocess.assert_called_with(
-            ['sudo', 'openstack', 'tripleo', 'deploy', '--standalone',
-             '--standalone-role', 'Undercloud', '--stack', 'undercloud',
-             '--local-domain=localdomain',
+            ['sudo', '--preserve-env', 'openstack', 'tripleo', 'deploy',
+             '--standalone', '--standalone-role', 'Undercloud', '--stack',
+             'undercloud', '--local-domain=localdomain',
              '--local-ip=192.168.24.1/24',
              '--templates=/usr/share/openstack-tripleo-heat-templates/',
+             '--networks-file=network_data_undercloud.yaml',
              '--heat-native', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'undercloud.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'use-dns-for-vips.yaml', '-e', '/home/stack/foo.yaml', '-e',
+             'use-dns-for-vips.yaml', '-e',
+             '/usr/share/openstack-tripleo-heat-templates/environments/'
+             'podman.yaml', '-e', '/home/stack/foo.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic.yaml',
              '-e',
@@ -480,16 +494,19 @@ class TestUndercloudInstall(TestPluginV1):
         self.cmd.take_action(parsed_args)
 
         mock_subprocess.assert_called_with(
-            ['sudo', 'openstack', 'tripleo', 'deploy', '--standalone',
-             '--standalone-role', 'Undercloud', '--stack', 'undercloud',
-             '--local-domain=localdomain',
+            ['sudo', '--preserve-env', 'openstack', 'tripleo', 'deploy',
+             '--standalone', '--standalone-role', 'Undercloud', '--stack',
+             'undercloud', '--local-domain=localdomain',
              '--local-ip=192.168.24.1/24',
              '--templates=/usr/share/openstack-tripleo-heat-templates/',
+             '--networks-file=network_data_undercloud.yaml',
              '--heat-native', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'undercloud.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'use-dns-for-vips.yaml', '-e', '/home/stack/foo.yaml', '-e',
+             'use-dns-for-vips.yaml', '-e',
+             '/usr/share/openstack-tripleo-heat-templates/environments/'
+             'podman.yaml', '-e', '/home/stack/foo.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic.yaml',
              '-e',
@@ -558,11 +575,12 @@ class TestUndercloudUpgrade(TestPluginV1):
         self.cmd.take_action(parsed_args)
 
         mock_subprocess.assert_called_with(
-            ['sudo', 'openstack', 'tripleo', 'deploy', '--standalone',
-             '--standalone-role', 'Undercloud', '--stack', 'undercloud',
-             '--local-domain=localdomain',
+            ['sudo', '--preserve-env', 'openstack', 'tripleo', 'deploy',
+             '--standalone', '--standalone-role', 'Undercloud', '--stack',
+             'undercloud', '--local-domain=localdomain',
              '--local-ip=192.168.24.1/24',
              '--templates=/usr/share/openstack-tripleo-heat-templates/',
+             '--networks-file=network_data_undercloud.yaml',
              '--upgrade', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'lifecycle/undercloud-upgrade-prepare.yaml',
@@ -570,7 +588,9 @@ class TestUndercloudUpgrade(TestPluginV1):
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'undercloud.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'use-dns-for-vips.yaml', '-e', '/home/stack/foo.yaml', '-e',
+             'use-dns-for-vips.yaml', '-e',
+             '/usr/share/openstack-tripleo-heat-templates/environments/'
+             'podman.yaml', '-e', '/home/stack/foo.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic.yaml',
              '-e',
@@ -620,11 +640,12 @@ class TestUndercloudUpgrade(TestPluginV1):
         self.cmd.take_action(parsed_args)
 
         mock_subprocess.assert_called_with(
-            ['sudo', 'openstack', 'tripleo', 'deploy', '--standalone',
-             '--standalone-role', 'Undercloud', '--stack', 'undercloud',
-             '--local-domain=localdomain',
+            ['sudo', '--preserve-env', 'openstack', 'tripleo', 'deploy',
+             '--standalone', '--standalone-role', 'Undercloud', '--stack',
+             'undercloud', '--local-domain=localdomain',
              '--local-ip=192.168.24.1/24',
              '--templates=/usr/share/openstack-tripleo-heat-templates/',
+             '--networks-file=network_data_undercloud.yaml',
              '--upgrade', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'lifecycle/undercloud-upgrade-prepare.yaml',
@@ -632,7 +653,9 @@ class TestUndercloudUpgrade(TestPluginV1):
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'undercloud.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'use-dns-for-vips.yaml', '-e', '/home/stack/foo.yaml', '-e',
+             'use-dns-for-vips.yaml', '-e',
+             '/usr/share/openstack-tripleo-heat-templates/environments/'
+             'podman.yaml', '-e', '/home/stack/foo.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic.yaml',
              '-e',
@@ -681,11 +704,12 @@ class TestUndercloudUpgrade(TestPluginV1):
         self.cmd.take_action(parsed_args)
 
         mock_subprocess.assert_called_with(
-            ['sudo', 'openstack', 'tripleo', 'deploy', '--standalone',
-             '--standalone-role', 'Undercloud', '--stack', 'undercloud',
-             '--local-domain=localdomain',
+            ['sudo', '--preserve-env', 'openstack', 'tripleo', 'deploy',
+             '--standalone', '--standalone-role', 'Undercloud', '--stack',
+             'undercloud', '--local-domain=localdomain',
              '--local-ip=192.168.24.1/24',
              '--templates=/usr/share/openstack-tripleo-heat-templates/',
+             '--networks-file=network_data_undercloud.yaml',
              '--upgrade', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'lifecycle/undercloud-upgrade-prepare.yaml',
@@ -693,7 +717,9 @@ class TestUndercloudUpgrade(TestPluginV1):
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'undercloud.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'use-dns-for-vips.yaml', '-e', '/home/stack/foo.yaml', '-e',
+             'use-dns-for-vips.yaml', '-e',
+             '/usr/share/openstack-tripleo-heat-templates/environments/'
+             'podman.yaml', '-e', '/home/stack/foo.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic.yaml',
              '-e',
@@ -742,11 +768,12 @@ class TestUndercloudUpgrade(TestPluginV1):
         self.cmd.take_action(parsed_args)
 
         mock_subprocess.assert_called_with(
-            ['sudo', 'openstack', 'tripleo', 'deploy', '--standalone',
-             '--standalone-role', 'Undercloud', '--stack', 'undercloud',
-             '--local-domain=localdomain',
+            ['sudo', '--preserve-env', 'openstack', 'tripleo', 'deploy',
+             '--standalone', '--standalone-role', 'Undercloud', '--stack',
+             'undercloud', '--local-domain=localdomain',
              '--local-ip=192.168.24.1/24',
              '--templates=/usr/share/openstack-tripleo-heat-templates/',
+             '--networks-file=network_data_undercloud.yaml',
              '-y', '--upgrade', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'lifecycle/undercloud-upgrade-prepare.yaml',
@@ -754,7 +781,9 @@ class TestUndercloudUpgrade(TestPluginV1):
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'undercloud.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'use-dns-for-vips.yaml', '-e', '/home/stack/foo.yaml', '-e',
+             'use-dns-for-vips.yaml', '-e',
+             '/usr/share/openstack-tripleo-heat-templates/environments/'
+             'podman.yaml', '-e', '/home/stack/foo.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic.yaml',
              '-e',
@@ -807,11 +836,12 @@ class TestUndercloudUpgrade(TestPluginV1):
         self.cmd.app_args.verbose_level = old_verbose
 
         mock_subprocess.assert_called_with(
-            ['sudo', 'openstack', 'tripleo', 'deploy', '--standalone',
-             '--standalone-role', 'Undercloud', '--stack', 'undercloud',
-             '--local-domain=localdomain',
+            ['sudo', '--preserve-env', 'openstack', 'tripleo', 'deploy',
+             '--standalone', '--standalone-role', 'Undercloud', '--stack',
+             'undercloud', '--local-domain=localdomain',
              '--local-ip=192.168.24.1/24',
              '--templates=/usr/share/openstack-tripleo-heat-templates/',
+             '--networks-file=network_data_undercloud.yaml',
              '--upgrade', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'lifecycle/undercloud-upgrade-prepare.yaml',
@@ -819,7 +849,9 @@ class TestUndercloudUpgrade(TestPluginV1):
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'undercloud.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
-             'use-dns-for-vips.yaml', '-e', '/home/stack/foo.yaml', '-e',
+             'use-dns-for-vips.yaml', '-e',
+             '/usr/share/openstack-tripleo-heat-templates/environments/'
+             'podman.yaml', '-e', '/home/stack/foo.yaml', '-e',
              '/usr/share/openstack-tripleo-heat-templates/environments/'
              'services/ironic.yaml',
              '-e',
